CA04-Cl09
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Portal links |
clickAndWait | link=Añadir portal link |
type | id_name_es | Secondary Portal Link Ca04-Cl09 (no link)
select | id_category | label=Secondary link
type | id_slug | secondary-portal-link-ca04-cl09-no-link
clickAndWait | _save |
open | / |
verifyTextPresent | Secondary Portal Link Ca04-Cl09 (no link) |
clickAndWait | //li[@id='portal-link-secondary-portal-link-ca04-cl09-no-link']/a/span |
verifyTextPresent | Inicio → Welcome to Merengue |
open | /admin/ |
clickAndWait | link=Portal links |
clickAndWait | link=Secondary Portal Link Ca04-Cl09 (no link) |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |